@@ -1,5 +1,6 @@
 dat <- read.table(textConnection(
-  gsub("\n", " ", "0 0 0 0 0 -0.270340178359072 -0.367828308500142 0.666980581124872 1.87088147328446
+  gsub("\n", " ", "0 0 0 0 0 -0.270340178359072 -0.367828308500142
+       0.666980581124872 1.87088147328446
        2.14548907684624 -0.480859313143032 -0.72911654245842 -0.490308602315934 -0.66152028906509
        -0.221049033806403 0.367003418871239 0.631073992586373 0.0487728723414486 0.762655178750436
        0.78574757843331 0.338239686422963 0.784206454089066 -2.14265084073625 2.11325193044223
